==> gwt-jackson-0.2.1.jar: com/github/nmorel/gwtjackson/client/ser/EnumJsonSerializer.java <==
/*
 * Copyright 2013 Nicolas Morel
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.nmorel.gwtjackson.client.ser;

import javax.annotation.Nonnull;
import java.io.IOException;

import com.github.nmorel.gwtjackson.client.JsonSerializationContext;
import com.github.nmorel.gwtjackson.client.JsonSerializer;
import com.github.nmorel.gwtjackson.client.stream.JsonWriter;

/**
 * Default {@link JsonSerializer} implementation for {@link Enum}.
 *
 * @author Nicolas Morel
 */
public class EnumJsonSerializer<E extends Enum<E>> extends JsonSerializer<E> {

    private static final EnumJsonSerializer<?> INSTANCE = new EnumJsonSerializer();

    /**
     * @return an instance of {@link EnumJsonSerializer}
     */
    @SuppressWarnings( "unchecked" )
    public static <E extends Enum<E>> EnumJsonSerializer<E> getInstance() {
        return (EnumJsonSerializer<E>) INSTANCE;
    }

    private EnumJsonSerializer() { }

    @Override
    public void doSerialize( JsonWriter writer, @Nonnull E value, JsonSerializationContext ctx ) throws IOException {
        writer.value( value.name() );
    }
}

==> gwt-jackson-0.12.0.jar: com/github/nmorel/gwtjackson/client/ser/EnumJsonSerializer.java <==
/*
 * Copyright 2013 Nicolas Morel
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.nmorel.gwtjackson.client.ser;

import javax.annotation.Nonnull;

import com.github.nmorel.gwtjackson.client.JsonSerializationContext;
import com.github.nmorel.gwtjackson.client.JsonSerializer;
import com.github.nmorel.gwtjackson.client.JsonSerializerParameters;
import com.github.nmorel.gwtjackson.client.stream.JsonWriter;

/**
 * Default {@link JsonSerializer} implementation for {@link Enum}.
 *
 * @author Nicolas Morel
 */
public class EnumJsonSerializer<E extends Enum<E>> extends JsonSerializer<E> {

    private static final EnumJsonSerializer<?> INSTANCE = new EnumJsonSerializer();

    /**
     * @return an instance of {@link EnumJsonSerializer}
     */
    @SuppressWarnings("unchecked")
    public static <S extends EnumJsonSerializer<?>> S getInstance() {
        return (S) INSTANCE;
    }

    private EnumJsonSerializer() { }

    @Override
    public void doSerialize( JsonWriter writer, @Nonnull E value, JsonSerializationContext ctx, JsonSerializerParameters params ) {
        writer.unescapeValue( value.name() );
    }
}
